@@ -391,6 +391,24 @@ class URLReplacerPreservingHighlightedEntity(PostprocessedMatchRegexReplacerAdap
         super().__init__(URL_REGEX, match_postprocessor, False, False, False)
 
 
+class EmailReplacerPreservingHighlightedEntity(PostprocessedMatchRegexReplacerAdapter):
+    """Replaces all e-mail-like entities, non-latin including. Includes length check for each entity part."""
+
+    def __init__(
+        self,
+        replace_with: str = "<email>",
+        start_with: str = "<email>",
+        end_with: str = "</email>",
+    ) -> None:
+        match_postprocessor = PreserveHighlightedEntity(
+            replace_with=replace_with,
+            start_with=start_with,
+            end_with=end_with
+        )
+        regex_query = r'[\w0-9][\w0-9._%+-]{0,63}@(?:[\w0-9<](?:[\w0-9-</>]{0,62}[\w0-9>])?\.){1,8}[\w</>]{2,63}'
+        super().__init__(regex_query, match_postprocessor, False, False, False)
+
+
 class EmailReplacer(RegexReplacerAdapter):
     """Replaces all e-mail-like entities, non-latin including. Includes length check for each entity part."""
 
@@ -543,6 +561,20 @@ class MultiPunctuationReplacer(RegexReplacerAdapter):
         super().__init__(regex_query, replace_tag_with * self.leave, False, False, False)
 
 
+class MultiNonLetterReplacer(RegexReplacerAdapter):
+
+    def __init__(self, include_digits: bool = False, max_allowed: int = 2, reduce_to: int = 2):
+        self.max = max_allowed
+        self.reduce_to = reduce_to
+        self.include_digits = include_digits
+        if self.include_digits:
+            regex_query = r'([\W\d_])\1{' + str(self.max) + ',}'
+        else:
+            regex_query = r'([\W_])\1{' + str(self.max) + ',}'
+
+        super().__init__(regex_query, '\\1' * self.reduce_to, False, False, False)
+
+
 class MultiLetterReplacer(RegexReplacerAdapter):
     """Replaces multiple consecutive letters ([^\W\d_]) with a number letters of this type (thus preserving possible
     doubling/tripling of letters but reducing possible exhaustive lettterrring."""
@@ -554,6 +586,20 @@ class MultiLetterReplacer(RegexReplacerAdapter):
         super().__init__(regex_query, replace_tag_with * self.leave, False, False, False)
 
 
+class MultiAllReplacer(RegexReplacerAdapter):
+
+    def __init__(self, include_digits: bool = False, max_allowed: int = 3, reduce_to: int = 3):
+        self.max = max_allowed
+        self.reduce_to = reduce_to
+        self.include_digits = include_digits
+        if self.include_digits:
+            regex_query = r'(.)\1{' + str(self.max) + ',}'
+        else:
+            regex_query = r'(\D)\1{' + str(self.max) + ',}'
+
+        super().__init__(regex_query, '\\1' * self.reduce_to, False, False, False)
+
+
 class NonWhitespaceAlphaNumPuncSpecSymbolsAllUnicodeReplacer(RegexReplacerAdapter):
     """Removes all unicode NON alpha-numeric, punctuation and special symbols (default keyboard set + some additional:
     ref to data/punctuation.txt, data/special_symbols.txt, data/currency.txt), whitespaces and emojis."""
