@@ -556,5 +556,35 @@ class StackingPreprocessorTest(unittest.TestCase):
         self.assertEqual(expected, output)
 
 
+class HighlightedUrlReplacerTest(unittest.TestCase):
+
+    def test_should_replace_url_with_one_highlight_preserved(self):
+        input_string = 'this is the link http://dostavka-gaza-v-<b>dom</b>.ru we need to replace.'
+        tokenizer = URLReplacerPreservingHighlightedEntity()
+        replacement = '<url><b>dom</b></url>'
+        expected = 'this is the link ' + replacement + ' we need to replace.'
+
+        result = tokenizer.preprocess(input_string)
+        self.assertEqual(expected, result)
+
+    def test_should_replace_url_with_two_highlights_preserved(self):
+        input_string = 'this is the link http://dostavka-gaza-v-<b>dom</b>.<b>ru</b> we need to replace.'
+        tokenizer = URLReplacerPreservingHighlightedEntity()
+        replacement = '<url><b>dom</b> <b>ru</b></url>'
+        expected = 'this is the link ' + replacement + ' we need to replace.'
+
+        result = tokenizer.preprocess(input_string)
+        self.assertEqual(expected, result)
+
+    def test_should_replace_url_without_highlight(self):
+        replacement = '<url/>'
+        input_string = 'this is the link http://dostavka-gaza-v-dom.ru we need to replace.'
+        tokenizer = URLReplacerPreservingHighlightedEntity(replace_with=replacement)
+        expected = 'this is the link ' + replacement + ' we need to replace.'
+
+        result = tokenizer.preprocess(input_string)
+        self.assertEqual(expected, result)
+
+
 if __name__ == '__main__':
     unittest.main()
